@@ -25,6 +25,20 @@ def get_data_folder(create_when_not_found=True):
     return './Data'
     #raise Exception('No "Data" folder found above current working directory! Please create dirctory: ".../Project/Data".')
 
+def zipDir(dirPath, zipPath, filter):
+    zipf = zipfile.ZipFile(zipPath , mode='w')
+    lenDirPath = len(dirPath)
+    for root, _, files in os.walk(dirPath):
+        for file in files:
+            filter_file=False
+            for f in filter:
+                if f in root or f in file+'\\':
+                    filter_file = True
+            if not filter_file:
+                filePath = os.path.join(root, file)
+                print(filePath)
+                zipf.write(filePath , filePath[lenDirPath :] )
+    zipf.close()
 
 class StorageManager:
 
@@ -184,11 +198,11 @@ class StorageManager:
     def load_np(self, key):
         return np.load(self.absolute_path + key + '.npy')
 
-    def copy_project_files(self):
+    def copy_project_files(self, base_folder='../../'):
         zf = zipfile.ZipFile(self.absolute_path+"backup.zip", "w")
-        for dirname, subdirs, files in os.walk('../../'):#
+        for dirname, subdirs, files in os.walk(base_folder):#
             #print(dirname, subdirs, files)
-            if dirname != '../../' and not 'Data' in dirname and not '.git' in dirname and not '.idea' in dirname:
+            if dirname != base_folder and not 'Data' in dirname and not '.git' in dirname and not '.idea' in dirname and not '.zip' in dirname:
                 zf.write(dirname)
                 for filename in files:
                     zf.write(os.path.join(dirname, filename))
